import express from "express";
import { authorizeRoles, isAuthenticatedUser } from "../../middlewares/auth.js";
import {
  createAnnouncemnet,
  getAnnouncements,
  getAnnouncementsByRole,
} from "./announcementController.js";
import { isAuthenticatedRD } from "../../middlewares/rdAuth.js";
import { isAuthenticatedSalesCoOrdinator } from "../../middlewares/SalesCoOrdinatorAuth.js";
import { isAuthenticatedTerritoryManager } from "../../middlewares/TerritoryManagerAuth.js";

const router = express.Router();

router
  .route("/announcement/create")
  .post(isAuthenticatedUser, authorizeRoles("admin"), createAnnouncemnet);
router
  .route("/announcement/get")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getAnnouncements);
router
  .route("/announcement/RDs")
  .get(isAuthenticatedRD, getAnnouncementsByRole);
router
  .route("/announcement/PDs")
  .get(isAuthenticatedUser, getAnnouncementsByRole);
router
  .route("/announcement/SCs")
  .get(isAuthenticatedSalesCoOrdinator, getAnnouncementsByRole);
router
  .route("/announcement/TMs")
  .get(isAuthenticatedTerritoryManager, getAnnouncementsByRole);

export default router;
