import mongoose from "mongoose";

const shippingAddressSchema = new mongoose.Schema(
  {
    Name: {
      type: String,
    },
    phoneNumber: {
      type: String,
    },
    street: {
      type: String,
      required: true,
    },
    district: {
      type: String,
      required: true,
    },
    city: {
      type: String,
      required: true,
      trim: true,
    },
    state: {
      type: String,
      required: true,
    },
    postalCode: {
      type: String,
      required: true,
      trim: true,
      validate: {
        validator: function (v) {
          return /^\d{6}$/.test(v);
        },
        message: "Postal code must be a 6-digit number",
      },
    },
    country: {
      type: String,
      required: true,
    },
    tradeName: {
      type: String,
      required: true,
    },
    isDefault: {
      type: Boolean,
      default: false,
    },
    user: {
      type: mongoose.Schema.Types.ObjectId,
      ref: "RetailDistributor",
      required: true,
    },
  },
  { timestamps: true, versionKey: false }
);

const ShippingAddressRD = mongoose.model("ShippingAddressRD", shippingAddressSchema);

export default ShippingAddressRD;
